@@ -1,5 +1,10 @@
 import frictionless
 
+import ckan.model as model
+from ckan.common import config
+
+from ckanext.datapackage_creator.model import Datapackage
+
 
 class BaseBackend(object):
 
@@ -9,7 +14,7 @@ class BaseBackend(object):
     def extract_resource(self, resource, *args, **kwargs):
         raise NotImplementedError()
 
-    def validate_resource(self, resource, *args, **kwargs):
+    def validate_package(self, package, *args, **kwargs):
         raise NotImplementedError()
 
 
@@ -21,8 +26,8 @@ class FritionlesseBackend(BaseBackend):
     def extract_resource(self, resource, *args, **kwargs):
         return frictionless.extract_resource(resource, *args, **kwargs)
 
-    def validate_resource(self, resource, *args, **kwargs):
-        raise NotImplementedError()
+    def validate_package(self, package, *args, **kwargs):
+        return frictionless.validate(package)
 
 
 default = FritionlesseBackend()
